==> microprofile-rest-client-tck-2.0.1-RC1-sources.jar: org/eclipse/microprofile/rest/client/tck/providers/ThreadedClientResponseFilter.java <==
/*
 * Copyright 2018 Contributors to the Eclipse Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.eclipse.microprofile.rest.client.tck.providers;

import java.io.IOException;

import javax.ws.rs.client.ClientRequestContext;
import javax.ws.rs.client.ClientResponseContext;
import javax.ws.rs.client.ClientResponseFilter;

public class ThreadedClientResponseFilter implements ClientResponseFilter{
    public final static String RESPONSE_THREAD_ID_HEADER = "Response-Thread-ID";
    public final static String RESPONSE_THREAD_NAME_HEADER = "Response-Thread-Name";
    private String responseThreadId;
    private String responseThreadName;

    @Override
    public void filter(ClientRequestContext clientRequestContext, ClientResponseContext clientResponseContext) throws IOException {
        responseThreadId = "" + Thread.currentThread().getId();
        clientResponseContext.getHeaders().putSingle(RESPONSE_THREAD_ID_HEADER, responseThreadId);
        responseThreadName = Thread.currentThread().getName();
        clientResponseContext.getHeaders().putSingle(RESPONSE_THREAD_NAME_HEADER, responseThreadName);
    }

    public String getResponseThreadId() {
        return responseThreadId;
    }

    public String getResponseThreadName() {
        return responseThreadName;
    }
}

==> microprofile-rest-client-tck-3.0-RC1-sources.jar: org/eclipse/microprofile/rest/client/tck/providers/ThreadedClientResponseFilter.java <==
/*
 * Copyright 2018, 2021 Contributors to the Eclipse Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.eclipse.microprofile.rest.client.tck.providers;

import java.io.IOException;

import jakarta.ws.rs.client.ClientRequestContext;
import jakarta.ws.rs.client.ClientResponseContext;
import jakarta.ws.rs.client.ClientResponseFilter;

public class ThreadedClientResponseFilter implements ClientResponseFilter {
    public final static String RESPONSE_THREAD_ID_HEADER = "Response-Thread-ID";
    public final static String RESPONSE_THREAD_NAME_HEADER = "Response-Thread-Name";
    private String responseThreadId;
    private String responseThreadName;

    @Override
    public void filter(ClientRequestContext clientRequestContext, ClientResponseContext clientResponseContext)
            throws IOException {
        responseThreadId = "" + Thread.currentThread().getId();
        clientResponseContext.getHeaders().putSingle(RESPONSE_THREAD_ID_HEADER, responseThreadId);
        responseThreadName = Thread.currentThread().getName();
        clientResponseContext.getHeaders().putSingle(RESPONSE_THREAD_NAME_HEADER, responseThreadName);
    }

    public String getResponseThreadId() {
        return responseThreadId;
    }

    public String getResponseThreadName() {
        return responseThreadName;
    }
}
